@@ -20,6 +20,7 @@ require_once __DIR__.\DIRECTORY_SEPARATOR.'Framework'.\DIRECTORY_SEPARATOR.'Vali
 require_once __DIR__.\DIRECTORY_SEPARATOR.'Framework'.\DIRECTORY_SEPARATOR.'AnnotationsConfig.php';
 require_once __DIR__.\DIRECTORY_SEPARATOR.'Framework'.\DIRECTORY_SEPARATOR.'SerializerConfig.php';
 require_once __DIR__.\DIRECTORY_SEPARATOR.'Framework'.\DIRECTORY_SEPARATOR.'PropertyAccessConfig.php';
+require_once __DIR__.\DIRECTORY_SEPARATOR.'Framework'.\DIRECTORY_SEPARATOR.'TypeInfoConfig.php';
 require_once __DIR__.\DIRECTORY_SEPARATOR.'Framework'.\DIRECTORY_SEPARATOR.'PropertyInfoConfig.php';
 require_once __DIR__.\DIRECTORY_SEPARATOR.'Framework'.\DIRECTORY_SEPARATOR.'CacheConfig.php';
 require_once __DIR__.\DIRECTORY_SEPARATOR.'Framework'.\DIRECTORY_SEPARATOR.'PhpErrorsConfig.php';
@@ -79,6 +80,7 @@ class FrameworkConfig implements \Symfony\Component\Config\Builder\ConfigBuilder
     private $annotations;
     private $serializer;
     private $propertyAccess;
+    private $typeInfo;
     private $propertyInfo;
     private $cache;
     private $phpErrors;
@@ -494,7 +496,7 @@ class FrameworkConfig implements \Symfony\Component\Config\Builder\ConfigBuilder
      * @template TValue
      * @param TValue $value
      * router configuration
-     * @default {"enabled":false,"cache_dir":"%kernel.cache_dir%","default_uri":null,"http_port":80,"https_port":443,"strict_requirements":true,"utf8":true}
+     * @default {"enabled":false,"cache_dir":"%kernel.build_dir%","default_uri":null,"http_port":80,"https_port":443,"strict_requirements":true,"utf8":true}
      * @return \Symfony\Config\Framework\RouterConfig|$this
      * @psalm-return (TValue is array ? \Symfony\Config\Framework\RouterConfig : static)
      */
@@ -704,6 +706,22 @@ class FrameworkConfig implements \Symfony\Component\Config\Builder\ConfigBuilder
         return $this->propertyAccess;
     }
 
+    /**
+     * Type info configuration
+     * @default {"enabled":true}
+    */
+    public function typeInfo(array $value = []): \Symfony\Config\Framework\TypeInfoConfig
+    {
+        if (null === $this->typeInfo) {
+            $this->_usedProperties['typeInfo'] = true;
+            $this->typeInfo = new \Symfony\Config\Framework\TypeInfoConfig($value);
+        } elseif (0 < \func_num_args()) {
+            throw new InvalidConfigurationException('The node created by "typeInfo()" has already been initialized. You cannot pass values the second time you call typeInfo().');
+        }
+
+        return $this->typeInfo;
+    }
+
     /**
      * Property info configuration
      * @default {"enabled":true}
@@ -1313,6 +1331,12 @@ class FrameworkConfig implements \Symfony\Component\Config\Builder\ConfigBuilder
             unset($value['property_access']);
         }
 
+        if (array_key_exists('type_info', $value)) {
+            $this->_usedProperties['typeInfo'] = true;
+            $this->typeInfo = new \Symfony\Config\Framework\TypeInfoConfig($value['type_info']);
+            unset($value['type_info']);
+        }
+
         if (array_key_exists('property_info', $value)) {
             $this->_usedProperties['propertyInfo'] = true;
             $this->propertyInfo = new \Symfony\Config\Framework\PropertyInfoConfig($value['property_info']);
@@ -1531,6 +1555,9 @@ class FrameworkConfig implements \Symfony\Component\Config\Builder\ConfigBuilder
         if (isset($this->_usedProperties['propertyAccess'])) {
             $output['property_access'] = $this->propertyAccess->toArray();
         }
+        if (isset($this->_usedProperties['typeInfo'])) {
+            $output['type_info'] = $this->typeInfo->toArray();
+        }
         if (isset($this->_usedProperties['propertyInfo'])) {
             $output['property_info'] = $this->propertyInfo->toArray();
         }
